import { useState, type FormEventHandler } from "react";
// This is a copy paste from https://github.com/InseeFrLab/keycloakify/blob/main/src/lib/pages/Login.tsx
// You can replace all relative imports by cherry picking files from the keycloakify module.  
// For example, the following import:  
// import { clsx } from "./tools/clsx";
// becomes:  
import { clsx } from "keycloakify/lib/tools/clsx";
import { useConstCallback } from "keycloakify/lib/tools/useConstCallback";
import type { PageProps } from "keycloakify/lib/KcProps";
// Here use your own KcContext and I18n that you might have overloaded.  
import type { KcContext } from "../kcContext";
import type { I18n } from "../i18n";

export default function Login(props: PageProps<Extract<KcContext, { pageId: "login.ftl"; }>, I18n>) {
	const { kcContext, i18n, doFetchDefaultThemeResources = true, Template, ...kcProps } = props;

	const { social, realm, url, usernameEditDisabled, login, auth, registrationDisabled } = kcContext;

	const { msg, msgStr } = i18n;

	const [isLoginButtonDisabled, setIsLoginButtonDisabled] = useState(false);

	const onSubmit = useConstCallback<FormEventHandler<HTMLFormElement>>(e => {
		e.preventDefault();

		setIsLoginButtonDisabled(true);

		const formElement = e.target as HTMLFormElement;

		//NOTE: Even if we login with email Keycloak expect username and password in
		//the POST request.
		formElement.querySelector("input[name='email']")?.setAttribute("name", "username");

		formElement.submit();
	});

	return (
		<Template
			{...{ kcContext, i18n, doFetchDefaultThemeResources, ...kcProps }}
			displayInfo={social.displayInfo}
			displayWide={realm.password && social.providers !== undefined}
			headerNode={msg("doLogIn")}
			formNode={
				<div id="kc-form" className={clsx(realm.password && social.providers !== undefined && kcProps.kcContentWrapperClass)}>
					<div
						id="kc-form-wrapper"
						className={clsx(
							realm.password && social.providers && [kcProps.kcFormSocialAccountContentClass, kcProps.kcFormSocialAccountClass]
						)}
					>
						{realm.password && (
							<form id="kc-form-login" onSubmit={onSubmit} action={url.loginAction} method="post">
								<div className={clsx(kcProps.kcFormGroupClass)}>
									{(() => {
										const label = !realm.loginWithEmailAllowed
											? "username"
											: realm.registrationEmailAsUsername
												? "email"
												: "usernameOrEmail";

										const autoCompleteHelper: typeof label = label === "usernameOrEmail" ? "username" : label;

										return (
											<>
												<label htmlFor={autoCompleteHelper} className={clsx(kcProps.kcLabelClass)}>
													{msg(label)}
												</label>
												<input
													tabIndex={1}
													id={autoCompleteHelper}
													className={clsx(kcProps.kcInputClass)}
													//NOTE: This is used by Google Chrome auto fill so we use it to tell
													//the browser how to pre fill the form but before submit we put it back
													//to username because it is what keycloak expects.
													name={autoCompleteHelper}
													defaultValue={login.username ?? ""}
													type="text"
													{...(usernameEditDisabled
														? { "disabled": true }
														: {
															"autoFocus": true,
															"autoComplete": "off"
														})}
												/>
											</>
										);
									})()}
								</div>
								<div className={clsx(kcProps.kcFormGroupClass)}>
									<label htmlFor="password" className={clsx(kcProps.kcLabelClass)}>
										{msg("password")}
									</label>
									<input
										tabIndex={2}
										id="password"
										className={clsx(kcProps.kcInputClass)}
										name="password"
										type="password"
										autoComplete="off"
									/>
								</div>
								<div className={clsx(kcProps.kcFormGroupClass, kcProps.kcFormSettingClass)}>
									<div id="kc-form-options">
										{realm.rememberMe && !usernameEditDisabled && (
											<div className="checkbox">
												<label>
													<input
														tabIndex={3}
														id="rememberMe"
														name="rememberMe"
														type="checkbox"
														{...(login.rememberMe
															? {
																"checked": true
															}
															: {})}
													/>
													{msg("rememberMe")}
												</label>
											</div>
										)}
									</div>
									<div className={clsx(kcProps.kcFormOptionsWrapperClass)}>
										{realm.resetPasswordAllowed && (
											<span>
												<a tabIndex={5} href={url.loginResetCredentialsUrl}>
													{msg("doForgotPassword")}
												</a>
											</span>
										)}
									</div>
								</div>
								<div id="kc-form-buttons" className={clsx(kcProps.kcFormGroupClass)}>
									<input
										type="hidden"
										id="id-hidden-input"
										name="credentialId"
										{...(auth?.selectedCredential !== undefined
											? {
												"value": auth.selectedCredential
											}
											: {})}
									/>
									<input
										tabIndex={4}
										className={clsx(
											kcProps.kcButtonClass,
											kcProps.kcButtonPrimaryClass,
											kcProps.kcButtonBlockClass,
											kcProps.kcButtonLargeClass
										)}
										name="login"
										id="kc-login"
										type="submit"
										value={msgStr("doLogIn")}
										disabled={isLoginButtonDisabled}
									/>
								</div>
							</form>
						)}
					</div>
					{realm.password && social.providers !== undefined && (
						<div id="kc-social-providers" className={clsx(kcProps.kcFormSocialAccountContentClass, kcProps.kcFormSocialAccountClass)}>
							<ul
								className={clsx(
									kcProps.kcFormSocialAccountListClass,
									social.providers.length > 4 && kcProps.kcFormSocialAccountDoubleListClass
								)}
							>
								{social.providers.map(p => (
									<li key={p.providerId} className={clsx(kcProps.kcFormSocialAccountListLinkClass)}>
										<a href={p.loginUrl} id={`zocial-${p.alias}`} className={clsx("zocial", p.providerId)}>
											<span>{p.displayName}</span>
										</a>
									</li>
								))}
							</ul>
						</div>
					)}
				</div>
			}
			infoNode={
				realm.password &&
				realm.registrationAllowed &&
				!registrationDisabled && (
					<div id="kc-registration">
						<span>
							{msg("noAccount")}
							<a tabIndex={6} href={url.registrationUrl}>
								{msg("doRegister")}
							</a>
						</span>
					</div>
				)
			}
		/>
	);
}
